@@ -127,7 +127,7 @@ has uid =>
 	required => 0,
 );
 
-our $VERSION = '2.02';
+our $VERSION = '2.03';
 
 # --------------------------------------------------
 # For accepted and rejected by Marpa, see
@@ -247,8 +247,6 @@ string_char_set			~ escaped_char
 :lexeme					~ undirected_edge			pause => before		event => undirected_edge	priority => 2
 undirected_edge			~ '--'
 
-# Lexemes in alphabetical order.
-
 # Boilerplate.
 
 :discard				~ whitespace
@@ -263,8 +261,8 @@ END_OF_GRAMMAR
 		({
 			source => \$self -> bnf
 		})
-
 	);
+
 	$self -> recce
 	(
 		Marpa::R2::Scanless::R -> new
@@ -305,7 +303,7 @@ END_OF_GRAMMAR
 	my($index)     = 1; # 0 => prolog, 1 => graph.
 	my($stack)     = $self -> stack;
 
-	push @$stack, $daughters[1];
+	push @$stack, $daughters[$index];
 
 	$self -> stack($stack);
 
@@ -356,16 +354,6 @@ sub clean_before
 
 # --------------------------------------------------
 
-sub _get_graph_from_command_line
-{
-	my($self) = @_;
-
-	$self -> graph_text($self -> description);
-
-} # End of _get_graph_from_command_line.
-
-# --------------------------------------------------
-
 sub log
 {
 	my($self, $level, $s) = @_;
@@ -382,17 +370,17 @@ sub _process
 	my($string)     = $self -> clean_before($self -> graph_text);
 	my($length)     = length $string;
 	my($last_event) = '';
-	my($format)     = '%-20s    %5s    %5s    %-s';
+	my($format)     = '%-20s    %5s    %5s    %5s    %-s';
+
+	$self -> log(debug => sprintf($format, 'Event', 'Start', 'Span', 'Pos', 'Lexeme') );
 
 	# We use read()/lexeme_read()/resume() because we pause at each lexeme.
 
-	my($event_name, $edge);
+	my($event_name);
 	my(@fields);
 	my($lexeme, $literal);
 	my($span, $start);
 
-	$self -> log(debug => sprintf($format, 'Event', 'Start', 'Span', 'Lexeme') );
-
 	for
 	(
 		my $pos = $self -> recce -> read(\$string);
@@ -406,7 +394,7 @@ sub _process
 		$literal        = substr($string, $start, $pos - $start);
 		$lexeme         = $self -> recce -> literal($start, $span);
 
-		$self -> log(debug => sprintf($format, $event_name, $start, $span, $lexeme) );
+		$self -> log(debug => sprintf($format, $event_name, $start, $span, $pos, $lexeme) );
 
 		if ($event_name eq 'attribute_name')
 		{
@@ -730,10 +718,14 @@ sub run
 
 	if ($self -> description)
 	{
-		$self -> _get_graph_from_command_line;
+		# Assume graph is a single line without comments.
+
+		$self -> graph_text($self -> description);
 	}
 	elsif ($self -> input_file)
 	{
+		# Quick removal of whole-line C++ and hash comments.
+
 		$self -> graph_text(join(' ', grep{! m!^(?:#|//)!} read_file($self -> input_file, binmode => ':encoding(utf-8)') ) );
 	}
 	else
@@ -765,10 +757,10 @@ sub run
 		$self -> log(error => "Parse failed. Error: $_");
 	};
 
-	# Return 0 for success and 1 for failure.
-
 	$self -> log(info => "Parse result: $result (0 is success)");
 
+	# Return 0 for success and 1 for failure.
+
 	return $result;
 
 } # End of run.
@@ -1372,7 +1364,9 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=MarpaX::Demo::StringParser>.
 
 L<MarpaX::Demo::StringParser> was written by Ron Savage I<E<lt>ron@savage.net.auE<gt>> in 2013.
 
-Home page: L<http://savage.net.au/>.
+Marpa's homepage: <http://savage.net.au/Marpa.html>.
+
+My homepage: L<http://savage.net.au/>.
 
 =head1 Copyright
 
